# Contributing

:tada: Thanks for taking the time to contribute! :tada:

The following is a set of guidelines for contributing to this [repo](https://github.com/<user>/<repo>).
These are mostly guidelines, not rules. Use your best judgment, and feel free to propose changes to this document.

#### Table Of Contents

[Code of Conduct](#code-of-conduct)

[What should I know before I get started?](#what-should-i-know-before-i-get-started)

- [GNU Make and Bash](#make-and-bash)

[How Can I Contribute?](#how-can-i-contribute)

- [Reporting Bugs](#reporting-bugs)
- [Suggesting Enhancements](#suggesting-enhancements)
- [Your First Code Contribution](#your-first-code-contribution)
- [Pull Requests](#pull-requests)

[Styleguides](#styleguides)

- [Commit Messages](#commit-messages)
- [Code Styleguide](#code-styleguide)
- [Specs Styleguide](#specs-styleguide)
- [Docs Styleguide](#docs-styleguide)

[Additional Notes](#additional-notes)

- [Issue and Pull Request Labels](#issue-and-pull-request-labels)

## Code of Conduct

This project and everyone participating in it is governed by our [Code of Conduct](CODE_OF_CONDUCT.md). By participating, you are expected to uphold this code.

## What should I know before I get started?

### Make and Bash

- [Makefiles](https://www.gnu.org/software/make/manual/html_node/Introduction.html)
- [Bourne Again Shell](https://www.gnu.org/software/bash/manual/html_node/index.html#Top)

## How Can I Contribute?

### Reporting Bugs

### Suggesting Enhancements

### Your First Code Contribution

#### Local development

### Pull Requests

## Styleguides

### Git Commit Messages

### Specs Styleguide

## Additional Notes

### Issue and Pull Request Labels
